@@ -3,4 +3,4 @@ mkdir -p m4
 autopoint --force
 git submodule update --init --recursive
 AUTOPOINT='intltoolize --automake --copy' autoreconf -fiv -Wall || exit
-test -n "$NOCONFIGURE" || ./configure --enable-maintainer-mode "$@"
+test -n "$NOCONFIGURE" || ./configure "$@"
