@@ -1,7 +1,7 @@
 #include <libebook/libebook.h>
 #include <gtk/gtk.h>
 
-void contacts_ensure_eds_accounts (void);
+gboolean contacts_ensure_eds_accounts (gboolean allow_interaction);
 const char *contacts_lookup_esource_name_by_uid (const char *uid);
 const char *contacts_lookup_esource_name_by_uid_for_contact (const char *uid);
 gboolean contacts_esource_uid_is_google (const char *uid);
